@@ -83,10 +83,6 @@ geo_amenity_sf <- function(bbox,
   all_res <- NULL
 
   for (i in seq_len(length(amenity))) {
-    if (i > 1) {
-      Sys.sleep(1)
-    }
-
     res_single <- geo_amenity_sf_single(
       bbox = bbox,
       amenity = amenity[i],
@@ -163,21 +159,13 @@ geo_amenity_sf_single <- function(bbox,
 
   json <- tempfile(fileext = ".geojson")
 
-  # nocov start
-  res <- tryCatch(
-    download.file(url, json, mode = "wb", quiet = isFALSE(verbose)),
-    warning = function(e) {
-      return(NULL)
-    },
-    error = function(e) {
-      return(NULL)
-    }
-  )
+  res <- api_call(url, json, isFALSE(verbose))
 
-  if (is.null(res)) {
+  # nocov start
+  if (isFALSE(res)) {
     message(url, " not reachable.")
     result_out <- data.frame(query = amenity)
-    return(result_out)
+    return(invisible(result_out))
   }
 
   # nocov end
@@ -193,7 +181,7 @@ geo_amenity_sf_single <- function(bbox,
   if (length(names(sfobj)) == 1) {
     message("No results for query ", amenity)
     result_out <- data.frame(query = amenity)
-    return(result_out)
+    return(invisible(result_out))
   }
 
 
