@@ -64,10 +64,6 @@ geo_lite <- function(address,
   all_res <- NULL
 
   for (i in seq_len(length(address))) {
-    if (i > 1) {
-      Sys.sleep(1)
-    }
-
     res_single <- geo_lite_single(
       address = address[i],
       lat,
@@ -124,22 +120,14 @@ geo_lite_single <- function(address,
 
   json <- tempfile(fileext = ".json")
 
-  # nocov start
-  res <- tryCatch(
-    download.file(url, json, mode = "wb", quiet = isFALSE(verbose)),
-    warning = function(e) {
-      return(NULL)
-    },
-    error = function(e) {
-      return(NULL)
-    }
-  )
+  res <- api_call(url, json, quiet = isFALSE(verbose))
 
-  if (is.null(res)) {
+  # nocov start
+  if (isFALSE(res)) {
     message(url, " not reachable.")
     result_out <- tibble::tibble(query = address, a = NA, b = NA)
     names(result_out) <- c("query", lat, long)
-    return(result_out)
+    return(invisible(result_out))
   }
   # nocov end
 
@@ -160,7 +148,7 @@ geo_lite_single <- function(address,
     message("No results for query ", address)
     result_out <- tibble::tibble(query = address, a = NA, b = NA)
     names(result_out) <- c("query", lat, long)
-    return(result_out)
+    return(invisible(result_out))
   }
 
   # Rename
